@@ -1,6 +1,6 @@
 # -*- Mode: Python; python-indent-offset: 4 -*-
 #
-# Time-stamp: <2020-07-25 17:34:12 alex>
+# Time-stamp: <2021-08-24 16:39:48 alex>
 #
 
 """
@@ -16,5 +16,7 @@ from .devif import DeviceInterface
 from .network import Network
 from .ipaddress import IpAddress
 from .dns import DNS
+from .dns_zone import DNS_zone
+from .dns_record import DNS_record
 
 from .device_tools import list_devices
